# Changelog

## [0.3.10](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.9...v0.3.10) (2025-10-04)


### Bug Fixes

* id-token write ([fc2d049](https://github.com/BernhardRode/loxone-mcp-server/commit/fc2d049df823f0fbb778d093c9a4af32176f2e9f))
* remove token ([dc68e0e](https://github.com/BernhardRode/loxone-mcp-server/commit/dc68e0e5f0f488b3d3a268df33f96288584dbe38))

## [0.3.9](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.8...v0.3.9) (2025-10-04)


### Bug Fixes

* remove token ([7e8a384](https://github.com/BernhardRode/loxone-mcp-server/commit/7e8a3849946e2d353d5521e7f7a42af090ca0326))

## [0.3.8](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.7...v0.3.8) (2025-10-04)


### Bug Fixes

* add pip ([ce9ec2f](https://github.com/BernhardRode/loxone-mcp-server/commit/ce9ec2f5d9f1a1620e3eb6b1915a7aadfd348271))

## [0.3.7](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.6...v0.3.7) (2025-10-04)


### Bug Fixes

* remove trests ([9ef1def](https://github.com/BernhardRode/loxone-mcp-server/commit/9ef1def1d835ea70d7a099abc824415fd3c87591))

## [0.3.6](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.5...v0.3.6) (2025-10-04)


### Bug Fixes

* remove trests ([69e43e6](https://github.com/BernhardRode/loxone-mcp-server/commit/69e43e6ccaed9f2e11151173ee6f6ad48e1556ac))

## [0.3.5](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.4...v0.3.5) (2025-10-04)


### Bug Fixes

* only pcython 3.13 ([c3c2dbc](https://github.com/BernhardRode/loxone-mcp-server/commit/c3c2dbc296510efbefce4998fc6af8150180967f))

## [0.3.4](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.3...v0.3.4) (2025-10-04)


### Bug Fixes

* add pypi env ([cfda4cd](https://github.com/BernhardRode/loxone-mcp-server/commit/cfda4cd841e311268e3a43e9fdd00842a4532b37))
* only pcython 3.13 ([8ea0127](https://github.com/BernhardRode/loxone-mcp-server/commit/8ea01276a1800067f39a1d2a362c9c47a98fc814))

## [0.3.3](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.2...v0.3.3) (2025-10-04)


### Bug Fixes

* no second publish ([cbcf532](https://github.com/BernhardRode/loxone-mcp-server/commit/cbcf5320df46380a4b9d120d58f54a8e2efcef74))

## [0.3.2](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.1...v0.3.2) (2025-10-04)


### Bug Fixes

* try ([d3d1727](https://github.com/BernhardRode/loxone-mcp-server/commit/d3d1727ee5b4e39d2749173f3a45de78301ddac5))

## [0.3.1](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.3.0...v0.3.1) (2025-10-04)


### Bug Fixes

* remove caches ([3498924](https://github.com/BernhardRode/loxone-mcp-server/commit/3498924adc47ad36cf3b5c72d4287609f2b2bb33))

## [0.3.0](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.2.0...v0.3.0) (2025-10-04)


### Features

* add publish steps and smoke tests ([3f4317a](https://github.com/BernhardRode/loxone-mcp-server/commit/3f4317a620a01f1d759479ae8c0a32621fae1ac0))

## [0.2.0](https://github.com/BernhardRode/loxone-mcp-server/compare/v0.1.0...v0.2.0) (2025-10-04)


### Features

* upgrade to python 3.12 ([4f854a4](https://github.com/BernhardRode/loxone-mcp-server/commit/4f854a46ba2d7c335acf04c59713f99c44e99ef8))

## 0.1.0 (2025-10-04)


### Features

* relase v.0.1 ([f7fc065](https://github.com/BernhardRode/loxone-mcp-server/commit/f7fc0654dfae89acbbb2479855f005b7c14ec9c5))


### Bug Fixes

* pipeline PYPI_API_TOKEN error ([0bf4278](https://github.com/BernhardRode/loxone-mcp-server/commit/0bf4278d29d9e7b4bc4bf25d2b3154ce567062b2))
